import { BehaviorSubject } from 'rxjs';
import { InjectionToken, Injectable, Inject, NgModule } from '@angular/core';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class Theme {
    constructor() {
        this.palette = 'light';
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ThemesConfig {
}
/** @type {?} */
const THEMES_CONFIG = new InjectionToken('themes service config');
/** @type {?} */
const DEFAULT_THEMES_CONFIG = new ThemesConfig();
DEFAULT_THEMES_CONFIG.defaultThemeName = 'pip-blue-theme';
DEFAULT_THEMES_CONFIG.themes = [
    {
        name: 'candy-theme',
        palette: 'light'
    },
    {
        name: 'unicorn-dark-theme',
        palette: 'dark'
    },
    {
        name: 'pip-blue-theme',
        palette: 'light'
    },
    {
        name: 'pip-grey-theme',
        palette: 'light'
    },
    {
        name: 'pip-navy-theme',
        palette: 'light'
    },
    {
        name: 'pip-amber-theme',
        palette: 'light'
    },
    {
        name: 'pip-green-theme',
        palette: 'light'
    },
    {
        name: 'pip-orange-theme',
        palette: 'light'
    },
    {
        name: 'pip-pink-theme',
        palette: 'light'
    },
    {
        name: 'pip-dark-theme',
        palette: 'dark'
    },
    {
        name: 'pip-black-theme',
        palette: 'dark'
    },
    {
        name: 'bootbarn-warm-theme',
        palette: 'light'
    },
    {
        name: 'bootbarn-cool-theme',
        palette: 'light'
    },
    {
        name: 'bootbarn-mono-theme',
        palette: 'light'
    },
    {
        name: 'mst-black-theme',
        palette: 'light'
    },
    {
        name: 'mst-black-dark-theme',
        palette: 'dark'
    },
    {
        name: 'mst-mono-theme',
        palette: 'light'
    },
    {
        name: 'mst-orange-theme',
        palette: 'light'
    },
    {
        name: 'mst-orange-dark-theme',
        palette: 'dark'
    },
    {
        name: 'mst-elegant-theme',
        palette: 'dark'
    }
];
DEFAULT_THEMES_CONFIG.lsKey = 'theme';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class PipThemesService {
    /**
     * @param {?} config
     */
    constructor(config) {
        this.config = config;
        this._selectedTheme = new Theme();
        // Load theme name from the local storage
        /** @type {?} */
        const name = window.localStorage.getItem(this.config.lsKey);
        // Set theme name
        for (const theme of this.config.themes) {
            if (theme.name === name) {
                this._selectedTheme = theme;
                break;
            }
            else if (this._selectedTheme == null || theme.name === this.config.defaultThemeName) {
                this._selectedTheme = theme;
            }
        }
        // Create observables
        this._themes$ = new BehaviorSubject(this.config.themes);
        this._selectedTheme$ = new BehaviorSubject(this._selectedTheme);
        this._selectedThemeName$ = new BehaviorSubject(this._selectedTheme.name);
        this.selectedTheme = this._selectedTheme;
    }
    /**
     * @return {?}
     */
    get themes$() {
        return this._themes$;
    }
    /**
     * @return {?}
     */
    get themes() {
        return this.config.themes;
    }
    /**
     * @param {?} themes
     * @return {?}
     */
    set themes(themes) {
        this.config.themes = themes;
        this._themes$.next(themes);
    }
    /**
     * @return {?}
     */
    get selectedThemeName() {
        return this._selectedTheme && this._selectedTheme.name;
    }
    /**
     * @param {?} name
     * @return {?}
     */
    set selectedThemeName(name) {
        for (const theme of this.config.themes) {
            if (theme.name === name) {
                this.selectedTheme = theme;
                break;
            }
        }
    }
    /**
     * @return {?}
     */
    get selectedTheme$() {
        return this._selectedTheme$;
    }
    /**
     * @return {?}
     */
    get selectedTheme() {
        return this._selectedTheme;
    }
    /**
     * @param {?} theme
     * @return {?}
     */
    set selectedTheme(theme) {
        if (theme == null) {
            return;
        }
        // Save selected theme to local storage
        window.localStorage.setItem(this.config.lsKey, theme.name);
        // Remove old theme name as a class to body
        document.body.classList.remove(this._selectedTheme.name);
        this._selectedTheme = theme;
        this._selectedTheme$.next(this._selectedTheme);
        // Add new theme name as a class to body
        document.body.classList.add(theme.name);
    }
}
PipThemesService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
PipThemesService.ctorParameters = () => [
    { type: ThemesConfig, decorators: [{ type: Inject, args: [THEMES_CONFIG,] }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class PipThemesModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: PipThemesModule,
            providers: [
                PipThemesService,
                {
                    provide: THEMES_CONFIG,
                    useValue: DEFAULT_THEMES_CONFIG
                }
            ]
        };
    }
}
PipThemesModule.decorators = [
    { type: NgModule }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { PipThemesModule, PipThemesService, Theme, ThemesConfig, THEMES_CONFIG, DEFAULT_THEMES_CONFIG, DEFAULT_THEMES_CONFIG as ɵd, THEMES_CONFIG as ɵc, ThemesConfig as ɵb, PipThemesService as ɵa };

//# sourceMappingURL=pip-webui2-themes.js.map